@@ -156,11 +156,16 @@ class Bin:
         if type(binary) is list:
             return_list = []
             for number in binary:
-
+                wentinto = 0
+                if type(number) is int:
+                    number= str(int(str(number).replace("0b", "")))
+                    wentinto = 1
                 for non_binary in ['2', '3', '4', '5', '6', '7', '8', '9']:
                     if non_binary in number:
-
-                        binary = 0
+                        if wentinto == 1:
+                            return_list.append(return_type(number))
+                        else:
+                            binary = 0
 
 
 
@@ -185,21 +190,27 @@ class Bin:
                     
                     power += 1 #increase the power variable by one  
                 
-                try:
-                    return_list.append(return_type(decimal))
-                
-                except:
-                    return_list.append(return_type("0"))
+                if wentinto != 1:
+                    try:
+                        return_list.append(return_type(decimal))
+                    
+                    except:
+                        return_list.append(return_type("0"))
 
 
             return return_list
 
         else:
-
+            wentinto = 0
+            if type(binary) is int:
+                binary = str(int(str(binary).replace("0b", "")))
+                wentinto = 1
             for non_binary in ['2', '3', '4', '5', '6', '7', '8', '9']:
                 if non_binary in binary:
-
-                    raise TypeError('Invalid binary number')
+                    if wentinto == 1:
+                        return binary 
+                    else:
+                        raise TypeError('Invalid binary number')
 
             try:
                 binary = int(str(binary).replace('0b', ''))
@@ -336,14 +347,14 @@ class Letter:
             if letter != ' ': 
                 try:
                     
-                    cipher += MORSE_CODE_DICT[letter] + ' '
+                    cipher += MORSE_CODE_DICT[letter] + ' / '
                 
                 except:
                     raise Exception('Found invalid characters')
             else: 
                 cipher += ' '
     
-        return cipher 
+        return cipher[0:len(cipher)-2]
     
     Morse, morsecode, Morsecode, MorseCode = morse, morse, morse, morse
 
@@ -355,7 +366,7 @@ class Detect:
     def asciistring(input, return_type=str):
 
         if return_type == list:
-            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
+            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
 
                 return Letter.asciibinary(input)
             
@@ -363,7 +374,7 @@ class Detect:
                 return asciibinary.Letter(input)
         if return_type == str:
 
-            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
+            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
 
                 return ' '.join(Letter.asciibinary(input))
             
